==> cscec5b-rmat-impl-3.0.1-20230329.094120-143-sources.jar: com/ejianc/business/rmat/service/IMaterialService.java <==
package com.ejianc.business.rmat.service;

import com.ejianc.business.rmat.vo.MaterialVO;
import com.ejianc.framework.core.response.QueryParam;

import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * 材料公共接口
 * 
 * @author generator
 * 
 */
public interface IMaterialService {

    /**
     * 查询验收台账
     * @param param
     * @param type start-在场可启用，stop-在场可停用，rest-在场可退赔，lose-在场可遗失，report-验收台账，restNoUse-退赔不区分启用状态
     * @return
     */
    List<MaterialVO> queryCheckList(QueryParam param, String type);

    /**
     * 在场周转材参照
     * @param param
     * @return
     */
    List<MaterialVO> queryRmatList(QueryParam param);

    /**
     *  校验同一个合同只能存在一个自由态或审批中的单据（验收单、启用单、停用单、退赔单、遗失单、租金计算单）
     * @param contractId    合同主键
     * @param billType  待校验单据类型
     * @param billId    待校验单据主键
     * @param type 保存/弃审
     * @return
     */
    String validateContract(String contractId, String billType, Long billId, String type);

    /**
     * 获取最大单据日期（验收单、启用单、停用单、退赔单、遗失单、租金计算单，只取主表单据日期，包含未生效单据）
     * @param params    contractId，billType，billId
     * @return
     */
    Date getLastDate(Map<String, Object> params);

    /**
     * 获取同一天最大制单日期（验收单、启用单、停用单、退赔单、遗失单、租金计算单，只取主表单据日期，包含未生效单据）
     * @param params    contractId，billType，billId
     * @return
     */
    Map<Date, Date> getMaxTime(Map<String, Object> params);

    List<MaterialVO> proMaterialList(QueryParam param);

    /**
     * 查询验收台账(租金计算)
     * @param contractId
     * @param startDate
     * @param endDate
     * @return
     */
    List<MaterialVO> queryCalculateList(String contractId, Date startDate, Date endDate);
}

==> cscec5b-rmat-impl-3.0.1-20241011.033953-313-sources.jar: com/ejianc/business/rmat/service/IMaterialService.java <==
package com.ejianc.business.rmat.service;

import com.ejianc.business.rmat.vo.MaterialVO;
import com.ejianc.framework.core.response.QueryParam;

import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * 材料公共接口
 *
 * @author generator
 *
 */
public interface IMaterialService {

    /**
     * 查询验收台账
     * @param param
     * @param type start-在场可启用，stop-在场可停用，rest-在场可退赔，lose-在场可遗失，report-验收台账，restNoUse-退赔不区分启用状态
     * @param refDate
     * @return
     */
    List<MaterialVO> queryCheckList(QueryParam param, String type, Date refDate);

    /**
     * 在场周转材参照
     * @param param
     * @param refDate
     * @return
     */
    List<MaterialVO> queryRmatList(QueryParam param, Date refDate);

    /**
     *  校验同一个合同只能存在一个自由态或审批中的单据（验收单、启用单、停用单、退赔单、遗失单、租金计算单）
     * @param contractId    合同主键
     * @param billType  待校验单据类型
     * @param billId    待校验单据主键
     * @param type 保存/弃审
     * @return
     */
    String validateContract(String contractId, String billType, Long billId, String type);

    /**
     * 获取最大单据日期（验收单、启用单、停用单、退赔单、遗失单、租金计算单，只取主表单据日期，包含未生效单据）
     * @param params    contractId，billType，billId
     * @return
     */
    Date getLastDate(Map<String, Object> params);

    /**
     * 获取同一天最大制单日期（验收单、启用单、停用单、退赔单、遗失单、租金计算单，只取主表单据日期，包含未生效单据）
     * @param params    contractId，billType，billId
     * @return
     */
    Map<Date, Date> getMaxTime(Map<String, Object> params);

    List<MaterialVO> proMaterialList(QueryParam param);

    /**
     * 查询验收台账(租金计算)
     * @param contractId
     * @param startDate
     * @param endDate
     * @return
     */
    List<MaterialVO> queryCalculateList(String contractId, Date startDate, Date endDate);
}
